ImageClipboardCopyStrategy class
Resolves optional image bytes without imposing platform transport on core.
Supply a resolver on the request and a writer that supports the resulting MIME types. This strategy alone does not enable binary clipboard support.
- Inheritance
-
- Object
- CopyStrategy
- ImageClipboardCopyStrategy
Constructors
- ImageClipboardCopyStrategy()
-
const
Properties
- format → MarkdownCopyFormat
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- resolveImages → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copy(
MarkdownCopyRequest request) → Future< MarkdownCopyPayload> -
inherited
-
copySync(
MarkdownCopyRequest request) → MarkdownCopyPayload? -
Synchronous event serialization, when all providers support it.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited