MarkdownSyntaxRequest class
Context passed at a UTF-16 source boundary to a syntax extension.
offset is inclusive and end is exclusive. state is the previous successful result state for this rule at this offset, not a global grammar state. Use immutable state values; rollback does not deep-copy payloads.
Constructors
- MarkdownSyntaxRequest({required String source, required int offset, required int end, required MarkdownSyntaxContext context, required bool isFinal, Object? state})
-
const
Properties
- context → MarkdownSyntaxContext
-
final
- end → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFinal → bool
-
final
- offset → int
-
final
- remaining → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
- state → Object?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited